@@ -3,11 +3,14 @@ from typing import Optional
 import typer
 from rich.progress import Progress, SpinnerColumn, TextColumn
 
-from what_to_eat import config, controllers, validators, version_callback
+from what_to_eat import config, controllers, version_callback
 from what_to_eat.gateways import wolt
+from what_to_eat.gateways.location import LocationError
+from what_to_eat.gateways.wolt import WoltApiError
 from what_to_eat.models import Ordering, Sort
 from what_to_eat.services.profile import find_profile
 from what_to_eat.services.weights import EvaluateTechnique
+from what_to_eat.utils import handle, validators
 
 app = typer.Typer(no_args_is_help=True)
 
@@ -18,6 +21,7 @@ def common(_: bool = typer.Option(None, "--version", "-v", callback=version_call
 
 
 @app.command()
+@handle.exception(WoltApiError)
 def ls(
     restaurant: Optional[str] = typer.Argument(  # noqa: U007
         default=None,
@@ -31,9 +35,7 @@ def ls(
         help="Query search for restaurants",
         callback=validators.validate_query,
     ),
-    profile_name: Optional[str] = typer.Option(  # noqa: U007
-        None, "--profile", "-p", help="Profile name"
-    ),
+    profile_name: Optional[str] = typer.Option(None, "--profile", "-p", help="Profile name"),  # noqa: U007
     tag: Optional[str] = typer.Option(None, "--tag", "-t", help="Tag"),  # noqa: U007
     sort: Sort = typer.Option(
         Sort.NONE,
@@ -49,9 +51,7 @@ def ls(
         help=f"Ordering: {', '.join(Ordering.choices())}",
         case_sensitive=False,
     ),
-    limit: Optional[int] = typer.Option(  # noqa: U007
-        None, "--limit", "-l", help="Limit results"
-    ),
+    limit: Optional[int] = typer.Option(None, "--limit", "-l", help="Limit results"),  # noqa: U007
 ) -> None:
     """Finds best restaurants via Wolt API"""
     profile = find_profile(profile_name)
@@ -65,16 +65,13 @@ def ls(
 
     if restaurant:
         return controllers.restaurant_controller(items, restaurant)
-    return controllers.items_controller(
-        items, profile, query, tag, sort, ordering, limit
-    )
+    return controllers.items_controller(items, profile, query, tag, sort, ordering, limit)
 
 
 @app.command()
+@handle.exception(WoltApiError)
 def random(
-    profile_name: Optional[str] = typer.Option(  # noqa: U007
-        None, "--profile", "-p", help="Profile name"
-    ),
+    profile_name: Optional[str] = typer.Option(None, "--profile", "-p", help="Profile name"),  # noqa: U007
     tag: Optional[str] = typer.Option(None, "--tag", "-t", help="Tag"),  # noqa: U007
     technique: EvaluateTechnique = typer.Option(
         EvaluateTechnique.MIX,
@@ -96,6 +93,7 @@ def random(
 
 
 @app.command()
+@handle.exception(LocationError)
 def configure() -> None:
     """Create configuration file to your orders"""
     config.manage()
